This crate contains kube-rs compatible bindings for Kubernetes custom resources for the capabilities.3scale.net group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
capabilities.3scale.net/v1alpha1
Tenant
capabilities.3scale.net/v1beta1
ActiveDocApplicationBackendCustomPolicyDefinitionDeveloperAccountDeveloperUserOpenAPIProductProxyConfigPromote